@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-09-13 16:49:46
-@LastEditTime: 2021-10-08 15:08:13
+@LastEditTime: 2021-10-12 17:48:53
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -19,8 +19,6 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
     :description: 创建微信预订单
     """
     @filter_check_params("user_id,pay_order_no")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 创建微信预订单
@@ -62,7 +60,7 @@ class WechatVoucherOrderHandler(ClientBaseHandler):
             invoke_result_data = self.business_process_executed(invoke_result_data)
             return self.response_json_success(invoke_result_data.data)
         except Exception as ex:
-            self.logging_link_error("【创建微信预订单异常】" + str(ex))
+            self.logging_link_error("【创建微信预订单异常】" + traceback.format_exc())
             return self.response_json_error("fail", "请重新支付")
 
     def business_process_executing(self):
@@ -130,7 +128,7 @@ class WechatPayNotifyHandler(FrameBaseHandler):
             return self.write(wechat_pay_reponse.convert_response_xml("SUCCESS", True))
 
         except Exception as ex:
-            self.logging_link_error("【微信支付异步通知】" + str(ex) + ":" + str(xml_params))
+            self.logging_link_error("【微信支付异步通知】" + traceback.format_exc() + ":" + str(xml_params))
             return self.write(wechat_pay_reponse.convert_response_xml("数据异常", False))
 
     def business_process_executing(self):
@@ -184,7 +182,7 @@ class WechatRefundNotifyHandler(FrameBaseHandler):
             self.business_process_executed(req_info_dict)
             return self.write(wechat_refund_reponse.convert_response_xml("SUCCESS", True))
         except Exception as ex:
-            self.logging_link_error("【微信退款异步通知】" + str(ex)+":" + str(xml_params))
+            self.logging_link_error("【微信退款异步通知】" + traceback.format_exc() + ":" + str(xml_params))
             return self.write(wechat_refund_reponse.convert_response_xml("数据异常", False))
 
     def business_process_executing(self):
@@ -219,7 +217,7 @@ class WechatRefundNotifyHandler(FrameBaseHandler):
                 refund_order_model.update_table("refund_status=4", where="out_refund_no=%s", params=req_info_dict["refund_id"])
         except Exception as ex:
             db_transaction.rollback_transaction()
-            self.logging_link_error("微信退款异步通知:数据处理异常:" + str(ex))
+            self.logging_link_error("【微信退款异步通知数据处理异常】" + traceback.format_exc())
 
 
 
@@ -228,8 +226,6 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
     :description: 创建抖音预订单
     """
     @filter_check_params("user_id,pay_order_no")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 创建抖音预订单
@@ -270,7 +266,7 @@ class TiktokVoucherOrderHandler(ClientBaseHandler):
             invoke_result_data = self.business_process_executed(invoke_result_data)
             return self.response_json_success(invoke_result_data.data)
         except Exception as ex:
-            self.logging_link_error("【创建抖音预订单异常】" + str(ex))
+            self.logging_link_error("【创建抖音预订单异常】" + traceback.format_exc())
             return self.response_json_error("fail", "请重新支付")
 
     def business_process_executing(self):
@@ -335,7 +331,7 @@ class TiktokPayNotifyHandler(FrameBaseHandler):
             return self.write(tiktok_reponse.convert_response_json())
 
         except Exception as ex:
-            self.logging_link_error("【抖音支付异步通知】" + str(ex) +":"+ str(json_params))
+            self.logging_link_error("【抖音支付异步通知】" + traceback.format_exc() + ":" + str(json_params))
             return self.write(tiktok_reponse.convert_response_json(-1, "数据异常"))
 
     def business_process_executing(self):
@@ -400,7 +396,7 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
             return self.write(tiktok_reponse.convert_response_json())
 
         except Exception as ex:
-            self.logging_link_error("【抖音退款异步通知】" + str(ex) + ":" + str(json_params))
+            self.logging_link_error("【抖音退款异步通知】" + traceback.format_exc() + ":" + str(json_params))
             return self.write(tiktok_reponse.convert_response_json(-1, "数据异常"))
 
     def business_process_executing(self):
@@ -436,4 +432,4 @@ class TiktokRefundNotifyHandler(FrameBaseHandler):
                 refund_order_model.update_table("refund_status=4", where="refund_no=%s", params=[response_data["cp_refundno"]])
         except Exception as ex:
             db_transaction.rollback_transaction()
-            self.logging_link_error("抖音退款异步通知:数据处理异常:" + str(ex))
\ No newline at end of file
+            self.logging_link_error("【抖音退款异步通知数据处理异常】" + traceback.format_exc())
\ No newline at end of file
