@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-17 11:19:05
-@LastEditTime: 2021-09-18 17:51:31
+@LastEditTime: 2021-10-13 09:51:18
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -15,8 +15,6 @@ class TaskInfoListHandler(ClientBaseHandler):
     :description: 获取任务列表
     """
     @filter_check_params("act_id,tb_user_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取任务列表
@@ -38,7 +36,8 @@ class TaskInfoListHandler(ClientBaseHandler):
         invoke_result_data = self.business_process_executing(self.request_params)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        task_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, invoke_result_data.data["daily_repeat_browse"])
+        daily_repeat_browse = invoke_result_data.data["daily_repeat_browse"] if invoke_result_data.data.__contains__("daily_repeat_browse") else False
+        task_list = task_base_model.get_client_task_list(app_id, act_id, module_id, user_id, task_types, app_key, app_secret, is_log, daily_repeat_browse)
         return self.response_json_success(self.business_process_executed(task_list, self.request_params))
 
     def business_process_executing(self, request_params):
@@ -68,8 +67,6 @@ class ReceiveRewardHandler(ClientBaseHandler):
     :description: 处理领取任务奖励
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理领取任务奖励
@@ -147,8 +144,6 @@ class FreeGiftHandler(ClientBaseHandler):
     :description: 处理掌柜有礼、新人有礼、免费领取等相似任务
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理掌柜有礼、新人有礼、免费领取等相似任务
@@ -219,8 +214,6 @@ class OneSignHandler(ClientBaseHandler):
     :description: 处理单次签到任务
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理单次签到任务
@@ -291,8 +284,6 @@ class WeeklySignHandler(ClientBaseHandler):
     :description: 处理每周签到任务
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理每周签到任务
@@ -363,8 +354,6 @@ class CumulativeSignHandler(ClientBaseHandler):
     :description: 处理累计签到任务
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理累计签到任务
@@ -435,8 +424,6 @@ class InviteNewUserHandler(ClientBaseHandler):
     :description: 处理邀请新用户任务
     """
     @filter_check_params("act_id,tb_user_id,invite_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理邀请新用户任务
@@ -509,8 +496,6 @@ class InviteJoinMemberHandler(ClientBaseHandler):
     :description: 处理邀请加入会员任务
     """
     @filter_check_params("act_id,tb_user_id,invite_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理邀请加入会员任务
@@ -584,8 +569,6 @@ class CollectGoodsHandler(ClientBaseHandler):
     :description: 处理收藏商品任务
     """
     @filter_check_params("act_id,tb_user_id,login_token,goods_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理收藏商品任务
@@ -656,8 +639,6 @@ class BrowseGoodsHandler(ClientBaseHandler):
     :description: 处理浏览商品任务
     """
     @filter_check_params("act_id,tb_user_id,login_token,goods_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理浏览商品任务
@@ -729,8 +710,6 @@ class FavorStoreHandler(ClientBaseHandler):
     :description: 处理关注店铺
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理关注店铺
@@ -800,8 +779,6 @@ class JoinMemberHandler(ClientBaseHandler):
     :description: 处理加入店铺会员
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理加入店铺会员
@@ -871,8 +848,6 @@ class BrowseSiteHandler(ClientBaseHandler):
     :description: 处理浏览网址相关任务 如：浏览店铺、浏览直播间、浏览会场/专题
     """
     @filter_check_params("act_id,tb_user_id,login_token")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 处理浏览商品任务
