@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-28 09:15:49
-@LastEditTime: 2021-09-17 18:06:42
+@LastEditTime: 2021-10-10 15:42:27
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -16,8 +16,6 @@ class ThemeInfoHandler(ClientBaseHandler):
     :description: 获取主题（皮肤）信息
     """
     @filter_check_params("act_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取主题（皮肤）信息
@@ -44,8 +42,6 @@ class SaveThemeHandler(ClientBaseHandler):
     :description: 保存主题
     """
     @filter_check_params("out_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def post_async(self):
         """
         :description: 保存主题
@@ -75,8 +71,6 @@ class SaveSkinHandler(ClientBaseHandler):
     :description: 保存皮肤
     """
     @filter_check_params("theme_out_id,skin_out_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def post_async(self):
         """
         :description: 保存皮肤
@@ -107,8 +101,6 @@ class ThemeInfoListHandler(ClientBaseHandler):
     """
     :description: 获取主题信息列表
     """
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 保存皮肤
@@ -126,8 +118,6 @@ class SkinInfoListHandler(ClientBaseHandler):
     :description: 获取皮肤信息列表
     """
     @filter_check_params("theme_out_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 保存皮肤
