@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 18:31:06
-@LastEditTime: 2021-09-22 17:01:17
+@LastEditTime: 2021-10-11 17:53:30
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -21,8 +21,6 @@ class LoginHandler(ClientBaseHandler):
     :description: 登录处理
     """
     @filter_check_params("act_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 登录处理
@@ -99,8 +97,6 @@ class UpdateUserInfoHandler(ClientBaseHandler):
     :description: 更新用户信息
     """
     @filter_check_params("act_id,tb_user_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 更新用户信息
@@ -134,8 +130,6 @@ class CheckIsMemberHandler(ClientBaseHandler):
     """
     :description: 校验是否是店铺会员
     """
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 校验是否是店铺会员
@@ -161,8 +155,6 @@ class ApplyBlackUnbindHandler(ClientBaseHandler):
     :description: 提交黑名单解封申请
     """
     @filter_check_params("act_id,tb_user_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 提交黑名单解封申请
@@ -192,8 +184,6 @@ class GetCouponPrizeHandler(ClientBaseHandler):
     :description: 领取淘宝优惠券
     """
     @filter_check_params("user_prize_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 领取淘宝优惠券（发奖接口）
@@ -253,8 +243,6 @@ class UserAssetListHandler(ClientBaseHandler):
     :description: 获取用户资产列表
     """
     @filter_check_params("act_id,tb_user_id")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取用户资产列表
@@ -278,8 +266,6 @@ class AssetLogListHandler(ClientBaseHandler):
     :description: 资产流水记录
     """
     @filter_check_params("act_id,tb_user_id,asset_type")
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 资产流水记录
@@ -302,15 +288,13 @@ class AssetLogListHandler(ClientBaseHandler):
         asset_object_id = self.get_param("asset_object_id")
 
         asset_base_model = AssetBaseModel(context=self)
-        return self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, "", "", "", open_id, 0, ""))
+        return self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id))
 
 
 class GetJoinMemberUrlHandler(ClientBaseHandler):
     """
     :description: 获取加入会员地址
     """
-    @filter_check_head_sign()
-    @filter_check_params_sign()
     def get_async(self):
         """
         :description: 获取加入会员地址
