@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-12 20:11:48
-@LastEditTime: 2021-10-13 19:31:31
+@LastEditTime: 2021-10-15 11:36:45
 @LastEditors: HuangJianYi
 :description: 
 """
@@ -37,6 +37,7 @@ class FrameBaseHandler(BaseApiHandler):
         """
         if self.__class__.__name__ == "IndexHandler":
             return
+        self.is_encrypt = False
         #获取请求参数
         self._convert_request_params()
         # 标记日志请求关联
@@ -115,20 +116,24 @@ class FrameBaseHandler(BaseApiHandler):
             data = data.__dict__
         template_value = {}
         template_value['success'] = success
-        client_encrypt_type = config.get_value("client_encrypt_type", 0)
-        server_encrypt_type = config.get_value("server_encrypt_type", 0)
-        if ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
-            dv = SevenHelper.get_random(16)
-            encrypt_key = config.get_value("encrypt_key", "+YNX8UTLkcgD94M2")
-            app_id = self.get_argument("source_app_id", "", strip=True)
-            if not app_id:
-                app_id = config.get_value("app_id")
-            password = app_id[0:10] + encrypt_key[0:6] if len(app_id) >= 10 and len(encrypt_key) >= 6 else ""
-            iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
-            template_value['data'] = CryptographyHelper.aes_encrypt(self.json_dumps(data), password, iv)
-            template_value['dv'] = dv
-        else:
+        is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
+        if is_encrypt == False:
             template_value['data'] = data
+        else:
+            client_encrypt_type = config.get_value("client_encrypt_type", 0)
+            server_encrypt_type = config.get_value("server_encrypt_type", 0)
+            if ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+                dv = SevenHelper.get_random(16)
+                encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
+                app_id = self.get_argument("source_app_id", "", strip=True)
+                if not app_id:
+                    app_id = config.get_value("app_id")
+                password = str(encrypt_key).replace("1", "l")
+                iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
+                template_value['data'] = CryptographyHelper.aes_encrypt(self.json_dumps(data), password, iv)
+                template_value['dv'] = dv
+            else:
+                template_value['data'] = data
         template_value['error_code'] = error_code
         template_value['error_message'] = error_message
 
@@ -249,7 +254,7 @@ class FrameBaseHandler(BaseApiHandler):
                 continue
             if k == "signature_md5":
                 continue
-            request_sign_params[k] = v.replace(" ", "_seven_").replace("(", "_seven1_").replace(")", "_seven2_")
+            request_sign_params[k] = str(v).replace(" ", "_seven_").replace("(", "_seven1_").replace(")", "_seven2_")
         request_params_sorted = sorted(request_sign_params.items(), key=lambda e: e[0], reverse=False)
         request_message = "&".join(k + "=" + CodingHelper.url_encode(v) for k, v in request_params_sorted)
         request_message = request_message.replace("_seven_", "%20").replace("_seven1_", "(").replace("_seven2_", ")").replace("%27", "'")
@@ -329,69 +334,6 @@ class FrameBaseHandler(BaseApiHandler):
         self.set_header("Access-Control-Allow-Methods", "POST,GET,OPTIONS")
         self.set_header("Access-Control-Allow-Credentials", "true")
 
-    def _convert_request_params(self):
-        """
-        :Description: 转换请求参数
-        :last_editors: HuangJianYi
-        """
-        invoke_result_data = InvokeResultData()
-        self.request_params = {}
-        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密，2-md5加密
-        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #服务端加密类型 0-无，1-aes加密，2-md5加密
-        if ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
-            encrypt_key = config.get_value("encrypt_key", "+YNX8UTLkcgD94M2")
-            app_id = self.get_argument("source_app_id", "", strip=True)
-            if not app_id:
-                app_id = config.get_value("app_id")
-            password = app_id[0:10] + encrypt_key[0:6] if len(app_id) >= 10 and len(encrypt_key) >= 6 else ""
-            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
-                try:
-                    json_params = json.loads(self.request.body)
-                    if json_params:
-                        for field in json_params:
-                            self.request_params[field] = json_params[field]
-                        par = json_params["par"] if json_params.__contains__("par") else ""
-                        dv = json_params["dv"] if json_params.__contains__("dv") else ""
-                        iv = app_id[0:10] + str(json_params["dv"])[0:6] if len(str(json_params["dv"])) >= 6 else ""
-                        body_params = json.loads(CryptographyHelper.aes_decrypt(str(json_params["par"]), password, iv))
-                        for field in body_params:
-                            self.request_params[field] = body_params[field]
-                except:
-                    invoke_result_data.success = False
-                    invoke_result_data.error_code = "error"
-                    invoke_result_data.error_message = "参数解析错误"
-                    return invoke_result_data
-            else:
-                for field in self.request.arguments:
-                    self.request_params[field] = self.get_argument(field, "", strip=True)
-                if "par" in self.request.arguments and "dv" in self.request.arguments:
-                    par = self.get_argument("par", "", strip=True)
-                    dv = self.get_argument("dv", "", strip=True)
-                    iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
-                    try:
-                        body_params = json.loads(CryptographyHelper.aes_decrypt(par, password, iv))
-                        for field in body_params:
-                            self.request_params[field] = body_params[field]
-                    except:
-                        invoke_result_data.success = False
-                        invoke_result_data.error_code = "error"
-                        invoke_result_data.error_message = "参数解析错误"
-                        return invoke_result_data
-        else:
-            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
-                try:
-                    json_params = json.loads(self.request.body)
-                except:
-                    pass
-                if json_params:
-                    for field in json_params:
-                        self.request_params[field] = json_params[field]
-            else:
-                for field in self.request.arguments:
-                    self.request_params[field] = self.get_argument(field, "", strip=True)
-
-        return invoke_result_data
-
     def get_user_nick(self):
         """
         :description: 获取用户昵称
@@ -503,6 +445,70 @@ class FrameBaseHandler(BaseApiHandler):
 
         operation_log_model.add_entity(operation_log)
 
+    def _convert_request_params(self):
+        """
+        :Description: 转换请求参数
+        :last_editors: HuangJianYi
+        """
+        invoke_result_data = InvokeResultData()
+        self.request_params = {}
+        client_encrypt_type = config.get_value("client_encrypt_type", 0)  #客户端加密类型 0-无，1-aes加密，2-md5加密
+        server_encrypt_type = config.get_value("server_encrypt_type", 0)  #千牛端或后台加密类型 0-无，1-aes加密，2-md5加密
+        is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
+        if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+            encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
+            app_id = self.get_argument("source_app_id", "", strip=True)
+            if not app_id:
+                app_id = config.get_value("app_id")
+            password = str(encrypt_key).replace("1", "l")
+            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+                try:
+                    json_params = json.loads(self.request.body)
+                    if json_params:
+                        for field in json_params:
+                            self.request_params[field] = json_params[field]
+                        par = json_params["par"] if json_params.__contains__("par") else ""
+                        dv = json_params["dv"] if json_params.__contains__("dv") else ""
+                        iv = app_id[0:10] + str(json_params["dv"])[0:6] if len(str(json_params["dv"])) >= 6 else ""
+                        body_params = json.loads(CryptographyHelper.aes_decrypt(str(json_params["par"]), password, iv))
+                        for field in body_params:
+                            self.request_params[field] = body_params[field]
+                except:
+                    invoke_result_data.success = False
+                    invoke_result_data.error_code = "error"
+                    invoke_result_data.error_message = "参数解析错误"
+                    return invoke_result_data
+            else:
+                for field in self.request.arguments:
+                    self.request_params[field] = self.get_argument(field, "", strip=True)
+                if "par" in self.request.arguments and "dv" in self.request.arguments:
+                    par = self.get_argument("par", "", strip=True)
+                    dv = self.get_argument("dv", "", strip=True)
+                    iv = app_id[0:10] + str(dv)[0:6] if len(str(dv)) >= 6 else ""
+                    try:
+                        body_params = json.loads(CryptographyHelper.aes_decrypt(par, password, iv))
+                        for field in body_params:
+                            self.request_params[field] = body_params[field]
+                    except:
+                        invoke_result_data.success = False
+                        invoke_result_data.error_code = "error"
+                        invoke_result_data.error_message = "参数解析错误"
+                        return invoke_result_data
+        else:
+            if self.request.method == "POST" and "Content-Type" in self.request.headers and self.request.headers["Content-type"].lower().find("application/json") >= 0 and self.request.body:
+                try:
+                    json_params = json.loads(self.request.body)
+                except:
+                    pass
+                if json_params:
+                    for field in json_params:
+                        self.request_params[field] = json_params[field]
+            else:
+                for field in self.request.arguments:
+                    self.request_params[field] = self.get_argument(field, "", strip=True)
+
+        return invoke_result_data
+
 
 class ClientBaseHandler(FrameBaseHandler):
     """
@@ -546,7 +552,8 @@ class ClientBaseHandler(FrameBaseHandler):
             # 验证超时 10分钟过期
             client_encrypt_type = config.get_value("client_encrypt_type", 0)
             server_encrypt_type = config.get_value("server_encrypt_type", 0)
-            if ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
+            is_encrypt = False if hasattr(self, "is_encrypt") and self.is_encrypt == False else True
+            if is_encrypt == True and ("/server/" in self.request.uri and server_encrypt_type == 1) or ("/client/" in self.request.uri and client_encrypt_type == 1):
                 now_time = TimeHelper.get_now_timestamp(True)
                 if self.request_params.__contains__("timestamp") and (now_time - int(self.request_params["timestamp"]) > int(1000 * 60 * 10)):
                     self.response_json_error("timestamp", "超时操作")
@@ -619,6 +626,37 @@ class ClientBaseHandler(FrameBaseHandler):
         device_info_dict["signature_md5"] = "" if "signature_md5" not in info_model.keys() else info_model["signature_md5"][0]  # 签名md5
         return device_info_dict
 
+    def emoji_base64_to_emoji(self, text_str):
+        """
+        :description: 把加密后的表情还原
+        :param text_str: 加密后的字符串
+        :return: 解密后的表情字符串
+        :last_editors: HuangJianYi 
+        """
+        results = re.findall('\[em_(.*?)\]', text_str)
+        if results:
+            for item in results:
+                text_str = str(text_str).replace("[em_{0}]".format(item), CryptographyHelper.base64_decrypt(item))
+        return text_str
+
+    def emoji_to_emoji_base64(self, text_str):
+        """
+        :description: emoji表情转为[em_xxx]形式存于数据库,打包每一个emoji
+        :description: 性能遇到问题时重新设计转换程序
+        :param text_str: 未加密的字符串
+        :return: 解密后的表情字符串
+        :last_editors: HuangJianYi 
+        """
+        list_e = []
+        for i in text_str:
+            list_e.append(i)
+        for location, item_emoji in enumerate(text_str):
+            if item_emoji in unicode_codes.UNICODE_EMOJI:
+                bytes_item_emoji = item_emoji.encode("utf-8")
+                emoji_base64 = CryptographyHelper.base64_encrypt(bytes_item_emoji, "utf-8")
+                list_e[location] = "[em_" + emoji_base64 + "]"
+
+        return "".join(list_e)
 
 def filter_check_params(must_params=None):
     """
@@ -664,7 +702,7 @@ def filter_check_head_sign(is_check=True, no_check_params=None):
     """
     def check_head(handler):
         def wrapper(self, **args):
-            encrypt_key = config.get_value("encrypt_key", "+YNX8UTLkcgD94M2")
+            encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
             is_check_head = config.get_value("is_check_head", False)
             if is_check_head == False:
                 is_check = False
@@ -718,7 +756,7 @@ def filter_check_params_sign(is_check=True, no_check_params=None):
     """
     def check_params(handler):
         def wrapper(self, **args):
-            encrypt_key = config.get_value("encrypt_key", "+YNX8UTLkcgD94M2")
+            encrypt_key = config.get_value("encrypt_key", "r8C1JpyAXxrFV26V")
             client_encrypt_type = config.get_value("client_encrypt_type", 0)
             server_encrypt_type = config.get_value("server_encrypt_type", 0)
             if ("/server/" in self.request.uri and server_encrypt_type != 2) or ("/client/" in self.request.uri and client_encrypt_type != 2):
