@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-08-03 15:42:53
-@LastEditTime: 2021-10-13 09:40:24
+@LastEditTime: 2021-10-14 09:37:39
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -144,8 +144,17 @@ class UpdateActInfoHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
         self.create_operation_log(OperationType.update.value, "act_info_tb", "UpdateActInfoHandler", self.json_dumps(invoke_result_data.data["old"]), self.json_dumps(invoke_result_data.data["new"]))
+        self.business_process_executed(invoke_result_data)
         return self.response_json_success()
 
+    def business_process_executed(self, invoke_result_data):
+        """
+        :description: 执行后事件
+        :param invoke_result_data：执行后结果
+        :return:
+        :last_editors: HuangJianYi
+        """
+        return invoke_result_data
 
 class ActInfoListHandler(ClientBaseHandler):
     """
