@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-27 10:52:51
-@LastEditTime: 2021-09-23 16:38:02
+@LastEditTime: 2021-10-13 09:44:09
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -69,7 +69,7 @@ class LoginHandler(ClientBaseHandler):
         except:
             pass
 
-        self.response_json_success()
+        return self.response_json_success()
 
 
 class UpdateUserStatusHandler(ClientBaseHandler):
@@ -95,7 +95,7 @@ class UpdateUserStatusHandler(ClientBaseHandler):
         invoke_result_data = user_base_model.update_user_state(app_id, act_id, user_id, user_state)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
-        self.response_json_success()
+        return self.response_json_success()
 
 
 class UpdateUserStatusByBlackHandler(ClientBaseHandler):
@@ -123,7 +123,7 @@ class UpdateUserStatusByBlackHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
         self.business_process_executed(invoke_result_data)
-        self.response_json_success()
+        return self.response_json_success()
 
     def business_process_executing(self):
         """
@@ -172,7 +172,7 @@ class AuditUserBlackHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
         self.business_process_executed(invoke_result_data)
-        self.response_json_success()
+        return self.response_json_success()
 
     def business_process_executing(self):
         """
@@ -214,7 +214,7 @@ class UpdateAuditRemarkHandler(ClientBaseHandler):
         invoke_result_data = user_base_model.update_audit_remark(app_id, black_id, audit_remark)
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code, invoke_result_data.error_message)
-        self.response_json_success()
+        return self.response_json_success()
 
 
 class UserBlackListHandler(ClientBaseHandler):
@@ -250,7 +250,7 @@ class UserBlackListHandler(ClientBaseHandler):
         page_index = int(self.get_param("page_index", 0))
 
         user_base_model = UserBaseModel(context=self)
-        self.response_json_success(user_base_model.get_black_list(app_id, act_id, page_size, page_index, audit_status, user_id, start_date, end_date, user_nick, open_id))
+        return self.response_json_success(user_base_model.get_black_list(app_id, act_id, page_size, page_index, audit_status, user_id, start_date, end_date, user_nick, open_id))
 
 
 class UpdateUserAssetHandler(ClientBaseHandler):
@@ -291,7 +291,7 @@ class UpdateUserAssetHandler(ClientBaseHandler):
         if invoke_result_data.success == False:
             return self.response_json_error(invoke_result_data.error_code,invoke_result_data.error_message)
         self.business_process_executed(invoke_result_data)
-        self.response_json_success()
+        return self.response_json_success()
 
     def business_process_executing(self):
         """
@@ -357,7 +357,7 @@ class BatchUpdateUserAssetHandler(ClientBaseHandler):
                     asset_object_ids += ","
                 asset_object_ids += asset_object["asset_object_id"]
 
-        self.response_json_success()
+        return self.response_json_success()
 
 
 class AssetLogListHandler(ClientBaseHandler):
@@ -399,7 +399,7 @@ class AssetLogListHandler(ClientBaseHandler):
         asset_object_id = self.get_param("asset_object_id")
 
         asset_base_model = AssetBaseModel(context=self)
-        self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id))
+        return self.response_json_success(asset_base_model.get_asset_log_list(app_id, act_id, asset_type, page_size, page_index, user_id, asset_object_id, start_date, end_date, user_nick, user_open_id, source_type, source_object_id,"*",is_cache=False))
 
 
 class UserInfoListHandler(ClientBaseHandler):
