@@ -2,13 +2,14 @@
 """
 @Author: HuangJianYi
 @Date: 2021-10-08 22:01:47
-@LastEditTime: 2021-10-12 10:56:55
+@LastEditTime: 2021-10-15 14:26:05
 @LastEditors: HuangJianYi
 @Description: 
 """
 import json
 from Crypto.Cipher import AES
 import base64
+from seven_cloudapp_frame.libs.customize.seven_helper import *
 
 
 class CryptographyHelper:
@@ -46,7 +47,7 @@ class CryptographyHelper:
     @classmethod
     def aes_encrypt(self, source, password, iv, mode=AES.MODE_CBC, encoding="utf-8"):
         """
-        :Description: AES加密,ECB & ZeroPadding
+        :Description: AES加密,CBC & ZeroPadding
         :param source: 待加密字符串
         :param password: 密钥
         :param iv: 偏移量
@@ -66,10 +67,10 @@ class CryptographyHelper:
         count = len(source)
         if count < length:
             add = (length - count)
-            source = source + ('\01' * add).encode(encoding)
+            source = source + ('\0' * add).encode(encoding)
         elif count > length:
             add = (length - (count % length))
-            source = source + ('\01' * add).encode(encoding)
+            source = source + ('\0' * add).encode(encoding)
         cipher_text = cryptor.encrypt(source)
         # 因为AES加密时候得到的字符串不一定是ascii字符集的，输出到终端或者保存时候可能存在问题
         # 所以这里统一把加密后的字符串转化为base64
@@ -78,7 +79,7 @@ class CryptographyHelper:
     @classmethod
     def aes_decrypt(self, source, password, iv, mode=AES.MODE_CBC, encoding="utf-8"):
         """
-        :Description: AES解密,ECB & ZeroPadding
+        :Description: AES解密,CBC & ZeroPadding
         :param source: 待解密字符串
         :param password: 密钥
         :param iv: 偏移量
@@ -93,6 +94,8 @@ class CryptographyHelper:
             iv = iv.encode(encoding)
             cryptor = AES.new(password, mode, iv)
             plain_text = cryptor.decrypt(encry_text)
-            return str(plain_text, encoding).rstrip('\01').rstrip('\00')
+            plain_text = str(plain_text, encoding)
+            index = plain_text.rindex('}') + 1
+            return plain_text[0:index]
         except Exception as ex:
             return ""
