@@ -2,7 +2,7 @@
 """
 :Author: HuangJianYi
 :Date: 2021-07-15 11:54:54
-@LastEditTime: 2021-10-12 11:53:31
+@LastEditTime: 2021-10-15 11:48:24
 @LastEditors: HuangJianYi
 :description: 常用帮助类
 """
@@ -13,7 +13,7 @@ import random
 import datetime
 import re
 import ast
-from seven_cloudapp_frame.libs.customize.cryptography_helper import *
+
 
 
 class SevenHelper:
@@ -197,7 +197,7 @@ class SevenHelper:
     @classmethod
     def get_condition_by_str_list(self, field_name, str_list):
         """
-        :description: 根据str_list返回查询条件
+        :description: 根据str_list返回查询条件 in查询参数化，如：act_info_model.get_list("FIND_IN_SET(act_name,%s)", params=['活动1,活动2'])
         :param field_name: 字段名
         :param str_list: 字符串数组
         :return: 
@@ -211,7 +211,7 @@ class SevenHelper:
     @classmethod
     def get_condition_by_int_list(self, field_name, int_list=None):
         '''
-        :description: 根据int_list返回查询条件
+        :description: 根据int_list返回查询条件 in查询参数化，如：act_info_model.get_list("FIND_IN_SET(act_name,%s)", params=['活动1,活动2'])
         :param field_name:字段名
         :param int_list:整形数组
         :return: str
@@ -423,40 +423,6 @@ class SevenHelper:
         order_id = str(cur_time) + str(ran_num)
         return order_id
 
-    @classmethod
-    def emoji_base64_to_emoji(self, text_str):
-        """
-        :description: 把加密后的表情还原
-        :param text_str: 加密后的字符串
-        :return: 解密后的表情字符串
-        :last_editors: HuangJianYi 
-        """
-        results = re.findall('\[em_(.*?)\]', text_str)
-        if results:
-            for item in results:
-                text_str = text_str.replace("[em_{0}]".format(item), CryptographyHelper.base64_decrypt(item))
-        return text_str
-
-    @classmethod
-    def emoji_to_emoji_base64(self, text_str):
-        """
-        :description: emoji表情转为[em_xxx]形式存于数据库,打包每一个emoji
-        :description: 性能遇到问题时重新设计转换程序
-        :param text_str: 未加密的字符串
-        :return: 解密后的表情字符串
-        :last_editors: HuangJianYi 
-        """
-        list_e = []
-        for i in text_str:
-            list_e.append(i)
-        for location, item_emoji in enumerate(text_str):
-            if item_emoji in unicode_codes.UNICODE_EMOJI:
-                bytes_item_emoji = item_emoji.encode("utf-8")
-                emoji_base64 = CryptographyHelper.base64_encrypt(bytes_item_emoji, "utf-8")
-                list_e[location] = "[em_" + emoji_base64 + "]"
-
-        return "".join(list_e)
-
     @classmethod
     def json_dumps(self, rep_dic):
         """
