@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-01-14 10:44:07
-@LastEditTime: 2021-09-28 15:46:54
+@LastEditTime: 2021-10-12 17:52:14
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -68,10 +68,10 @@ class TikTokHelper:
             invoke_result_data.data = response_data
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【code2_session】" + str(ex) + ":" + str(response.text))
+            self.logger_error.error("【code2_session】" + traceback.format_exc() + ":" + str(response.text))
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = str(ex)
+            invoke_result_data.error_message = traceback.format_exc()
             return invoke_result_data
 
     @classmethod
@@ -107,10 +107,10 @@ class TikTokHelper:
             invoke_result_data.data = response_data["data"]
             return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【get_access_token】" + str(ex) + ":" + str(response.text))
+            self.logger_error.error("【get_access_token】" + traceback.format_exc() + ":" + str(response.text))
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = str(ex)
+            invoke_result_data.error_message = traceback.format_exc()
             return invoke_result_data
 
     @classmethod
@@ -139,7 +139,7 @@ class TikTokHelper:
             data_crypt = TikTokBizDataCrypt(app_id, session_key)
             data = data_crypt.decrypt(encrypted_Data, iv)  #data中是解密的信息
         except Exception as ex:
-            self.logger_error.error("【decrypt_data_by_code】" + str(ex))
+            self.logger_error.error("【decrypt_data_by_code】" + traceback.format_exc())
         return data
 
     @classmethod
@@ -161,7 +161,7 @@ class TikTokHelper:
             #data中是解密的信息
             data = data_crypt.decrypt(encrypted_Data, iv)
         except Exception as ex:
-            self.logger_error.error("【decrypt_data】" + str(ex))
+            self.logger_error.error("【decrypt_data】" + traceback.format_exc())
         return data
 
     @classmethod
@@ -199,10 +199,10 @@ class TikTokHelper:
                 return invoke_result_data
             return response_data
         except Exception as ex:
-            self.logger_error.error("【create_qr_code】" + str(ex) + ":" + str(response.text))
+            self.logger_error.error("【create_qr_code】" + traceback.format_exc() + ":" + str(response.text))
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
-            invoke_result_data.error_message = str(ex)
+            invoke_result_data.error_message = traceback.format_exc()
             return invoke_result_data
 
 
@@ -301,7 +301,7 @@ class TikTokPayRequest(object):
                 invoke_result_data.error_message = response_data['err_tips']
                 return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【创建预下单】" + str(ex))
+            self.logger_error.error("【创建预下单】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
             invoke_result_data.error_message = "创建预下单出现异常，请重试"
@@ -350,7 +350,7 @@ class TikTokPayRequest(object):
                 return invoke_result_data
 
         except Exception as ex:
-            self.logger_error.error("【查询订单】" + str(ex))
+            self.logger_error.error("【查询订单】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code="error"
             invoke_result_data.error_message = "查询订单出现异常，请重试"
@@ -422,7 +422,7 @@ class TikTokPayRequest(object):
                 invoke_result_data.data = response_data
                 return invoke_result_data
         except Exception as ex:
-            self.logger_error.error("【退款】" + str(ex))
+            self.logger_error.error("【退款】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "退款出现异常，请重试"
@@ -455,7 +455,7 @@ class TikTokPayRequest(object):
                 return invoke_result_data
 
         except Exception as ex:
-            self.logger_error.error("【退款查询】" + str(ex))
+            self.logger_error.error("【退款查询】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "退款查询出现异常，请重试"
@@ -503,7 +503,7 @@ class TikTokPayRequest(object):
                 return invoke_result_data
 
         except Exception as ex:
-            self.logger_error.error("【结算请求】" + str(ex))
+            self.logger_error.error("【结算请求】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "结算请求出现异常，请重试"
@@ -536,7 +536,7 @@ class TikTokPayRequest(object):
                 return invoke_result_data
 
         except Exception as ex:
-            self.logger_error.error("【结算查询】" + str(ex))
+            self.logger_error.error("【结算查询】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "error"
             invoke_result_data.error_message = "结算查询出现异常，请重试"
