@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2021-09-01 10:31:29
+@LastEditTime: 2021-10-12 17:56:15
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -112,7 +112,7 @@ class AssetConsoleModel():
                             asset_warn_notice_model.add_entity(asset_warn_notice)
 
                         except Exception as ex:
-                            logger_error.error(f"用户资产负数预警队列{mod_value}异常,json串:{SevenHelper.json_dumps(asset_log)},ex:{str(ex)}")
+                            logger_error.error(f"用户资产负数预警队列{mod_value}异常,json串:{SevenHelper.json_dumps(asset_log)},ex:{traceback.format_exc()}")
                             continue
                 else:
                     time.sleep(10)
@@ -200,7 +200,7 @@ class AssetConsoleModel():
                             warn_notice.notice_date = SevenHelper.get_now_datetime()
                             asset_warn_notice_model.update_entity(warn_notice,"is_notice,notice_date")
                         except Exception as ex:
-                            logger_error.error(f"推送预警通知异常,json串:{SevenHelper.json_dumps(warn_notice)},ex:{str(ex)}")
+                            logger_error.error(f"推送预警通知异常,json串:{SevenHelper.json_dumps(warn_notice)},ex:{traceback.format_exc()}")
                             continue
                 time.sleep(1)
             except Exception as ex:
@@ -257,7 +257,7 @@ class AssetConsoleModel():
                                 asset_warn_notice_model.add_entity(asset_warn_notice)
 
                         except Exception as ex:
-                            logger_error.error(f"资产每日进销存预警队列{mod_value}异常,json串:{SevenHelper.json_dumps(asset_inventory)},ex:{str(ex)}")
+                            logger_error.error(f"资产每日进销存预警队列{mod_value}异常,json串:{SevenHelper.json_dumps(asset_inventory)},ex:{traceback.format_exc()}")
                             continue
                 else:
                     time.sleep(60 * 60)
