@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-19 13:37:16
-@LastEditTime: 2021-09-10 15:58:51
+@LastEditTime: 2021-10-12 17:56:39
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -81,9 +81,9 @@ class StatConsoleModel():
                             is_add = True
                             if stat_orm.repeat_type > 0:
                                 if stat_orm.repeat_type == 2:
-                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_orm.act_id, stat_orm.module_id, stat_orm.id, stat_queue.user_id])
+                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id])
                                 else:
-                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_orm.act_id, stat_orm.module_id, stat_orm.id, stat_queue.user_id, now_day_int])
+                                    stat_log_total = stat_log_model.get_cache_total("act_id=%s and module_id=%s and orm_id=%s and user_id=%s and create_day=%s", params=[stat_queue.act_id, stat_queue.module_id, stat_orm.id, stat_queue.user_id, now_day_int])
                                 if stat_log_total > 0:
                                     is_add = False
 
@@ -124,10 +124,10 @@ class StatConsoleModel():
                             db_transaction.commit_transaction()
 
                         except Exception as ex:
-                            logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{str(ex)}")
+                            logger_error.error(f"统计队列{mod_value}异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{traceback.format_exc()}")
                             db_transaction.rollback_transaction()
                             stat_queue.process_count += 1
-                            stat_queue.process_result = f"出现异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{str(ex)}"
+                            stat_queue.process_result = f"出现异常,json串:{SevenHelper.json_dumps(stat_queue)},ex:{traceback.format_exc()}"
                             minute = 1 if stat_queue.process_count <= 5 else 5
                             stat_queue.process_date = TimeHelper.add_minutes_by_format_time(minute=minute)
                             stat_queue_model.update_entity(stat_queue, "process_count,process_result,process_date")
