@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-26 09:39:08
-@LastEditTime: 2021-09-10 13:37:17
+@LastEditTime: 2021-10-12 17:54:28
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -316,7 +316,7 @@ class StatBaseModel(FrameBaseModel):
                 stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], user_info_dict["open_id"], key_list_dict)
             
         except Exception as ex:
-            self.context.logging_link_error("【处理邀请上报】" + str(ex))
+            self.context.logging_link_error("【处理邀请上报】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"    
@@ -356,7 +356,7 @@ class StatBaseModel(FrameBaseModel):
                     stat_base_model.add_stat_list(app_id, act_id, module_id, user_info_dict["user_id"], user_info_dict["open_id"], key_list_dict)
 
         except Exception as ex:
-            self.context.logging_link_error("【处理分享上报】" + str(ex))
+            self.context.logging_link_error("【处理分享上报】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"    
