@@ -2,7 +2,7 @@
 """
 @Author: HuangJianYi
 @Date: 2021-07-22 11:10:20
-@LastEditTime: 2021-09-23 18:03:00
+@LastEditTime: 2021-10-12 17:55:48
 @LastEditors: HuangJianYi
 @Description: 
 """
@@ -222,7 +222,7 @@ class UserBaseModel(FrameBaseModel):
                 user_info.avatar = avatar if avatar else user_info.avatar
                 user_info.create_date = now_datetime
                 user_info.modify_date = now_datetime
-                user_info.login_token = SevenHelper.get_random(16, 1)
+                user_info.login_token = SevenHelper.get_random(16)
                 user_info_model.add_entity(user_info)
             else:
                 if user_info.app_id != app_id:
@@ -234,13 +234,13 @@ class UserBaseModel(FrameBaseModel):
                 user_info.avatar = user_account.avatar
                 user_info.is_new = 0
                 user_info.modify_date = now_datetime
-                user_info.login_token = SevenHelper.get_random(16, 1)
+                user_info.login_token = SevenHelper.get_random(16)
                 user_info_model.update_entity(user_info, "modify_date,login_token,is_new,user_nick,avatar")
                 
                 self._delete_user_info_cache(user_info.act_id,user_info.id_md5)
                     
         except Exception as ex:
-            self.context.logging_link_error("【获取或更新用户信息】" + str(ex))
+            self.context.logging_link_error("【获取或更新用户信息】" + traceback.format_exc())
         finally:
                 SevenHelper.redis_release_lock(acquire_lock_name, identifier)
         
@@ -308,7 +308,7 @@ class UserBaseModel(FrameBaseModel):
                 user_account_model.update_table(update_sql, "id=%s", params=params)
 
         except Exception as ex:
-            self.context.logging_link_error("【更新用户信息】" + str(ex))
+            self.context.logging_link_error("【更新用户信息】" + traceback.format_exc())
 
         return invoke_result_data
 
@@ -423,7 +423,7 @@ class UserBaseModel(FrameBaseModel):
 
         except Exception as ex:
             db_transaction.rollback_transaction()
-            self.context.logging_link_error("【更新用户状态黑名单】" + str(ex))
+            self.context.logging_link_error("【更新用户状态黑名单】" + traceback.format_exc())
             invoke_result_data.success = False
             invoke_result_data.error_code = "exception"
             invoke_result_data.error_message = "系统繁忙,请稍后再试"
@@ -707,7 +707,7 @@ class UserBaseModel(FrameBaseModel):
                         user_black_model.add_entity(user_black)
                     self._delete_user_info_cache(user_info_dict["act_id"],user_info_dict["id_md5"])
         except Exception as ex:
-            self.context.logging_link_error("【校验是否拉黑】" + str(ex))
+            self.context.logging_link_error("【校验是否拉黑】" + traceback.format_exc())
             result = False
         return result
  
